@@ -8,19 +8,22 @@
  *
  * @APPLE_LICENSE_HEADER_START@
  * 
- * The contents of this file constitute Original Code as defined in and
- * are subject to the Apple Public Source License Version 1.1 (the
- * "License").  You may not use this file except in compliance with the
- * License.  Please obtain a copy of the License at
- * http://www.apple.com/publicsource and read it before using this file.
+ * Copyright (c) 1999-2003 Apple Computer, Inc.  All Rights Reserved.
  * 
- * This Original Code and all software distributed under the License are
- * distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, EITHER
+ * This file contains Original Code and/or Modifications of Original Code
+ * as defined in and that are subject to the Apple Public Source License
+ * Version 2.0 (the 'License'). You may not use this file except in
+ * compliance with the License. Please obtain a copy of the License at
+ * http://www.opensource.apple.com/apsl/ and read it before using this
+ * file.
+ * 
+ * The Original Code and all software distributed under the License are
+ * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
  * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
  * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
- * FITNESS FOR A PARTICULAR PURPOSE OR NON-INFRINGEMENT.  Please see the
- * License for the specific language governing rights and limitations
- * under the License.
+ * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
+ * Please see the License for the specific language governing rights and
+ * limitations under the License.
  * 
  * @APPLE_LICENSE_HEADER_END@
  *
@@ -1025,9 +1028,16 @@ IOReturn	AppleDACAAudio::performDeviceWake () {
 	temp = myAudioI2SControl->GetSerialFormatReg();
 	temp = myAudioI2SControl->GetDataWordSizesReg();
 	if ( NULL != keyLargo ) {
-		//	Turn ON the I2S clocks
-		keyLargo->callPlatformFunction ( OSSymbol::withCString ( "keyLargo_powerI2S" ), false, (void*)true, (void*)0, 0, 0 );
-		IODelay ( 100 );
+		const OSSymbol * theSymbol;
+		
+		theSymbol = OSSymbol::withCString ( "keyLargo_powerI2S" );
+		
+		if (theSymbol) {
+			//	Turn ON the I2S clocks
+			keyLargo->callPlatformFunction (theSymbol , false, (void*)true, (void*)0, 0, 0 );
+			IODelay ( 100 );
+			theSymbol->release ();
+		}	
 	}
 	//	Restore I2S registers	(rbm 11 Oct 2002)
 	myAudioI2SControl->setSampleParameters(kDACA_FRAME_RATE, 0, &clockSource, &mclkDivisor, &sclkDivisor, kSndIOFormatI2S32x);
@@ -1086,9 +1096,15 @@ IOReturn	AppleDACAAudio::performDeviceSleep () {
 		closeI2C();
 	}
 	if ( NULL != keyLargo ) {
-		//	Turn OFF the I2S clocks
-		IODelay ( 100 );
-		keyLargo->callPlatformFunction ( OSSymbol::withCString ( "keyLargo_powerI2S" ), false, (void*)false, (void*)0, 0, 0 );
+		const OSSymbol * theSymbol;
+		theSymbol = OSSymbol::withCString ( "keyLargo_powerI2S" );
+		
+		if (theSymbol) {
+			//	Turn OFF the I2S clocks
+			IODelay ( 100 );
+			keyLargo->callPlatformFunction ( theSymbol, false, (void*)false, (void*)0, 0, 0 );
+			theSymbol->release ();
+		}	
 	}
 	temp = myAudioI2SControl->GetSerialFormatReg();
 	temp = myAudioI2SControl->GetDataWordSizesReg();
