@@ -3,19 +3,22 @@
  *
  * @APPLE_LICENSE_HEADER_START@
  * 
- * The contents of this file constitute Original Code as defined in and
- * are subject to the Apple Public Source License Version 1.1 (the
- * "License").  You may not use this file except in compliance with the
- * License.  Please obtain a copy of the License at
- * http://www.apple.com/publicsource and read it before using this file.
+ * Copyright (c) 1999-2003 Apple Computer, Inc.  All Rights Reserved.
  * 
- * This Original Code and all software distributed under the License are
- * distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, EITHER
+ * This file contains Original Code and/or Modifications of Original Code
+ * as defined in and that are subject to the Apple Public Source License
+ * Version 2.0 (the 'License'). You may not use this file except in
+ * compliance with the License. Please obtain a copy of the License at
+ * http://www.opensource.apple.com/apsl/ and read it before using this
+ * file.
+ * 
+ * The Original Code and all software distributed under the License are
+ * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
  * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
  * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
- * FITNESS FOR A PARTICULAR PURPOSE OR NON-INFRINGEMENT.  Please see the
- * License for the specific language governing rights and limitations
- * under the License.
+ * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
+ * Please see the License for the specific language governing rights and
+ * limitations under the License.
  * 
  * @APPLE_LICENSE_HEADER_END@
  */
@@ -164,6 +167,8 @@ protected:
 	Boolean					dallasSpeakersProbed;						// So we only probe the speakers once when they are plugged in
 	Boolean					hasANDedReset;								//	[2855519]
 	UInt32					gPowerState;
+	Boolean					powerStateChangeInProcess;
+	Boolean					codecResetFlag;
 
 	// information specific to the chip
 	Boolean					gModemSoundActive;
@@ -174,6 +179,8 @@ protected:
 	UInt32					sclkDivisor;
 	SoundFormat				serialFormat;
 
+	const OSSymbol *		mKeyLargoPowerI2SSymbol;
+
     // Hardware register manipulation
     virtual void 		sndHWInitialize(IOService *provider) ;
 	virtual void		sndHWPostDMAEngineInit (IOService *provider);
@@ -272,6 +279,7 @@ protected:
 	static IOReturn	DeviceInterruptServiceAction (OSObject *owner, void *arg1, void *arg2, void *arg3, void *arg4);
 	void		DeviceInterruptService (void);
 	IOReturn	GetCustomEQCoefficients (UInt32 layoutID, UInt32 deviceID, UInt32 speakerID, EQPrefsElementPtr *filterSettings);
+	Boolean		usesDigitalPlaythrough ( void );
 	UInt32		GetDeviceMatch (void);
 	IOReturn	SndHWSetOutputBiquad( UInt32 streamID, UInt32 biquadRefNum, FourDotTwenty *biquadCoefficients );
 	IOReturn	SndHWSetOutputBiquadGroup( UInt32 biquadFilterCount, FourDotTwenty *biquadCoefficients );
@@ -362,6 +370,7 @@ protected:
 	UInt32				mActiveOutput;		//	set to kSndHWOutputNone at init
 	UInt32				mActiveInput;		//	set to kSndHWInputNone at init
 	UInt32				gInputNoneAlias;	
+	Boolean				mNeedBalanceAdjust;
 
 	UInt8 *				getGPIOAddress (UInt32 gpioSelector);
 	void				GpioWriteByte( UInt8* gpioAddress, UInt8 data );
