@@ -17,7 +17,7 @@ EQPrefs         theEQPrefs =
 {
     0x00000001,                         // structVersionNumber
     0x72617720,                         // genreType = 'raw '
-    0x0000000D,                         // eqCount	(update EQPrefsElement array size in AppleTexas2EQPrefs.cpp when updating eqCount!)
+    0x00000010,                         // eqCount	(update EQPrefsElement array size in AppleTexas2EQPrefs.cpp when updating eqCount!)
     0x00000000,                         // nameID
     {                                   // eq
         {                               // ----------     Equalization Set #1     ----------
@@ -395,6 +395,93 @@ EQPrefs         theEQPrefs =
 				{{{ 0x0E, 0x92, 0x4C }, { 0xE6, 0xDC, 0x31 }, { 0x0D, 0x01, 0x97 }, { 0xE6, 0xDC, 0x31 }, { 0x0B, 0x93, 0xE3 }}}, // Right Biquad 4
 				{{{ 0x0F, 0xB9, 0xAC }, { 0xE1, 0xBA, 0xFA }, { 0x0E, 0xE5, 0xFE }, { 0xE1, 0xBA, 0xFA }, { 0x0E, 0x9F, 0xAA }}}, // Right Biquad 5
 				{{{ 0x0D, 0x4B, 0x33 }, { 0x03, 0x63, 0x8F }, { 0x0A, 0xE0, 0xD2 }, { 0x03, 0x63, 0x8F }, { 0x08, 0x2C, 0x06 }}}, // Right Biquad 6
+            }                           // end of filter set
+		},
+		{                               // ----------     Equalization Set #14     ----------
+            /*  44100.0 */   44100,     // filterSampleRate
+            /*     1.0  */       3,     // drcCompressionRatioNumerator
+            /*     1.0  */       1,     // drcCompressionRatioDenominator
+            /*     0.0  */   	 0,     // drcThreshold     (X1000)
+            /*     0.0  */       0,     // drcMaximumVolume (X2)
+            0x00000000,                 // drcEnable    = disabled
+            0x00000027,                 // layoutID     = Q41
+            0x00000001,                 // deviceID     = kSndHWInternalSpeaker
+            0x00000000,                 // speakerID    = Built In
+            0x00000000,                 // reserved     = 0 
+            0x0000000E,                 // filterCount  = 14
+            {                           // filter coefficients in sets of:  b0, b1, b2, a1, a2 and are in 4.20 format
+				{{{ 0x0F, 0xB2, 0x5C }, { 0xE0, 0x9B, 0x46 }, { 0x0F, 0xB2, 0x5C }, { 0xE0, 0x9C, 0xBE }, { 0x0F, 0x66, 0x32 }}}, // Left Biquad 0
+				{{{ 0x08, 0xA8, 0x11 }, { 0x00, 0xE8, 0x4A }, { 0x01, 0x80, 0x85 }, { 0xF7, 0x84, 0xDC }, { 0x03, 0x8C, 0x05 }}}, // Left Biquad 1
+				{{{ 0x0F, 0xD7, 0x89 }, { 0xE3, 0x8C, 0x1C }, { 0x0F, 0x03, 0x6A }, { 0xE3, 0x8C, 0x1C }, { 0x0E, 0xDA, 0xF3 }}}, // Left Biquad 2
+				{{{ 0x0F, 0xBB, 0x05 }, { 0xE0, 0xF9, 0xAD }, { 0x0F, 0x67, 0x5F }, { 0xE0, 0xF9, 0xAD }, { 0x0F, 0x22, 0x64 }}}, // Left Biquad 3
+				{{{ 0x0F, 0xCB, 0xED }, { 0xE1, 0x16, 0x59 }, { 0x0F, 0x59, 0x4B }, { 0xE1, 0x16, 0x59 }, { 0x0F, 0x25, 0x39 }}}, // Left Biquad 4
+				{{{ 0x0F, 0xB5, 0x30 }, { 0xE2, 0xEE, 0x7E }, { 0x0E, 0xB2, 0x7F }, { 0xE2, 0xEE, 0x7E }, { 0x0E, 0x67, 0xAF }}}, // Left Biquad 5
+				{{{ 0x0E, 0xE5, 0x9D }, { 0x00, 0xF4, 0xC1 }, { 0x0C, 0x33, 0x61 }, { 0x00, 0xF4, 0xC1 }, { 0x0B, 0x18, 0xFE }}}, // Left Biquad 6
+				{{{ 0x0F, 0xB2, 0x5C }, { 0xE0, 0x9B, 0x46 }, { 0x0F, 0xB2, 0x5C }, { 0xE0, 0x9C, 0xBE }, { 0x0F, 0x66, 0x32 }}}, // Right Biquad 0
+				{{{ 0x08, 0xA8, 0x11 }, { 0x00, 0xE8, 0x4A }, { 0x01, 0x80, 0x85 }, { 0xF7, 0x84, 0xDC }, { 0x03, 0x8C, 0x05 }}}, // Right Biquad 1
+				{{{ 0x0F, 0xD7, 0x89 }, { 0xE3, 0x8C, 0x1C }, { 0x0F, 0x03, 0x6A }, { 0xE3, 0x8C, 0x1C }, { 0x0E, 0xDA, 0xF3 }}}, // Right Biquad 2
+				{{{ 0x0F, 0xBB, 0x05 }, { 0xE0, 0xF9, 0xAD }, { 0x0F, 0x67, 0x5F }, { 0xE0, 0xF9, 0xAD }, { 0x0F, 0x22, 0x64 }}}, // Right Biquad 3
+				{{{ 0x0F, 0xCB, 0xED }, { 0xE1, 0x16, 0x59 }, { 0x0F, 0x59, 0x4B }, { 0xE1, 0x16, 0x59 }, { 0x0F, 0x25, 0x39 }}}, // Right Biquad 4
+				{{{ 0x0F, 0xB5, 0x30 }, { 0xE2, 0xEE, 0x7E }, { 0x0E, 0xB2, 0x7F }, { 0xE2, 0xEE, 0x7E }, { 0x0E, 0x67, 0xAF }}}, // Right Biquad 5
+				{{{ 0x0E, 0xE5, 0x9D }, { 0x00, 0xF4, 0xC1 }, { 0x0C, 0x33, 0x61 }, { 0x00, 0xF4, 0xC1 }, { 0x0B, 0x18, 0xFE }}} // Right Biquad 6
+			}
+		},
+		{                               // ----------     Equalization Set #15     ----------
+            /*  44100.0 */   44100,     // filterSampleRate
+            /*     1.6  */       3,     // drcCompressionRatioNumerator
+            /*     1.6  */       1,     // drcCompressionRatioDenominator
+            /*   -10.5  */  -10500,     // drcThreshold     (X1000)
+            /*    +3.0  */       6,     // drcMaximumVolume (X2)
+            0x00000001,                 // drcEnable    = ENABLED
+            0x00000023,                 // layoutID     = Q16
+            0x00000001,                 // deviceID     = kSndHWInternalSpeaker
+            0x00000000,                 // speakerID    = Built In
+            0x00000000,                 // reserved     = 0 
+            0x0000000E,                 // filterCount  = 14
+            {                           // filter coefficients in sets of:  b0, b1, b2, a1, a2 and are in 4.20 format
+				{{{ 0x0F, 0x3B, 0xB8 }, { 0xE1, 0x88, 0x8E }, { 0x0F, 0x3B, 0xA2 }, { 0xE1, 0x8D, 0x5F }, { 0x0E, 0x7C, 0x43 }}}, // Left Biquad 0
+				{{{ 0x0F, 0xBF, 0xD1 }, { 0xE1, 0x80, 0x0A }, { 0x0F, 0x16, 0x85 }, { 0xE1, 0x80, 0x0A }, { 0x0E, 0xD6, 0x57 }}}, // Left Biquad 1
+				{{{ 0x0F, 0xD3, 0xAC }, { 0xE0, 0xF3, 0xF5 }, { 0x0F, 0x46, 0x2F }, { 0xE0, 0xF3, 0xF5 }, { 0x0F, 0x19, 0xDC }}}, // Left Biquad 2
+				{{{ 0x0E, 0xF5, 0x3C }, { 0xE4, 0xB6, 0x6E }, { 0x0D, 0xA6, 0xAB }, { 0xE4, 0xB6, 0x6E }, { 0x0C, 0x9B, 0xE7 }}}, // Left Biquad 3
+				{{{ 0x0F, 0x38, 0xF4 }, { 0xE2, 0x06, 0xB6 }, { 0x0E, 0xE5, 0x5A }, { 0xE2, 0x06, 0xB6 }, { 0x0E, 0x1E, 0x4F }}}, // Left Biquad 4
+				{{{ 0x0F, 0x79, 0x9A }, { 0xE6, 0x0A, 0x77 }, { 0x0D, 0xF4, 0xAC }, { 0xE6, 0x0A, 0x77 }, { 0x0D, 0x6E, 0x47 }}}, // Left Biquad 5
+				{{{ 0x05, 0x9A, 0x40 }, { 0x00, 0xA9, 0xB1 }, { 0x03, 0xC3, 0x6C }, { 0x00, 0xA9, 0xB1 }, { 0xF9, 0x5D, 0xAC }}}, // Left Biquad 6
+				{{{ 0x0F, 0x3B, 0xB8 }, { 0xE1, 0x88, 0x8E }, { 0x0F, 0x3B, 0xA2 }, { 0xE1, 0x8D, 0x5F }, { 0x0E, 0x7C, 0x43 }}}, // Right Biquad 0
+				{{{ 0x0F, 0xBF, 0xD1 }, { 0xE1, 0x80, 0x0A }, { 0x0F, 0x16, 0x85 }, { 0xE1, 0x80, 0x0A }, { 0x0E, 0xD6, 0x57 }}}, // Right Biquad 1
+				{{{ 0x0F, 0xD3, 0xAC }, { 0xE0, 0xF3, 0xF5 }, { 0x0F, 0x46, 0x2F }, { 0xE0, 0xF3, 0xF5 }, { 0x0F, 0x19, 0xDC }}}, // Right Biquad 2
+				{{{ 0x0E, 0xF5, 0x3C }, { 0xE4, 0xB6, 0x6E }, { 0x0D, 0xA6, 0xAB }, { 0xE4, 0xB6, 0x6E }, { 0x0C, 0x9B, 0xE7 }}}, // Right Biquad 3
+				{{{ 0x0F, 0x38, 0xF4 }, { 0xE2, 0x06, 0xB6 }, { 0x0E, 0xE5, 0x5A }, { 0xE2, 0x06, 0xB6 }, { 0x0E, 0x1E, 0x4F }}}, // Right Biquad 4
+				{{{ 0x0F, 0x79, 0x9A }, { 0xE6, 0x0A, 0x77 }, { 0x0D, 0xF4, 0xAC }, { 0xE6, 0x0A, 0x77 }, { 0x0D, 0x6E, 0x47 }}}, // Right Biquad 5
+				{{{ 0x05, 0x9A, 0x40 }, { 0x00, 0xA9, 0xB1 }, { 0x03, 0xC3, 0x6C }, { 0x00, 0xA9, 0xB1 }, { 0xF9, 0x5D, 0xAC }}} // Right Biquad 6
+			}
+		},
+		{                               // ----------     Equalization Set #16     ----------
+            /*  44100.0 */   44100,     // filterSampleRate
+            /*     3.0  */       3,     // drcCompressionRatioNumerator
+            /*     1.0  */       1,     // drcCompressionRatioDenominator
+            /*    -9.0  */   -9000,     // drcThreshold     (X1000)
+            /*    -0.0  */       0,     // drcMaximumVolume (X2)
+            0x00000001,                 // drcEnable    = ENABLED
+            0x00000028,                 // layoutID     = (as appropriate)
+            0x00000001,                 // deviceID     = internal speaker
+            0x00000000,                 // speakerID    = (as appropriate)
+            0x00000000,                 // reserved     = 0 
+            0x0000000E,                 // filterCount  = 14
+            {                           // filter coefficients in sets of:  b0, b1, b2, a1, a2 and are in 4.20 format
+				{{{ 0x0F, 0x9D, 0x90 }, { 0xE0, 0xC4, 0xDF }, { 0x0F, 0x9D, 0x90 }, { 0xE0, 0xC7, 0x3C }, { 0x0F, 0x3D, 0x7E }}},
+				{{{ 0x10, 0x52, 0x4F }, { 0xE2, 0x03, 0x59 }, { 0x0D, 0xDD, 0xA6 }, { 0xE1, 0xF8, 0x58 }, { 0x0E, 0x24, 0xF4 }}},
+				{{{ 0x0F, 0xDC, 0x22 }, { 0xF9, 0xD7, 0x33 }, { 0x0E, 0x35, 0x83 }, { 0xF9, 0xD7, 0x33 }, { 0x0E, 0x11, 0xA6 }}},
+				{{{ 0x0F, 0xB6, 0xEE }, { 0xE0, 0xF2, 0xD6 }, { 0x0F, 0x6E, 0x2D }, { 0xE0, 0xF2, 0xD6 }, { 0x0F, 0x25, 0x1B }}},
+				{{{ 0x0F, 0x90, 0x6B }, { 0xEF, 0x92, 0xF7 }, { 0x0D, 0x52, 0x87 }, { 0xEF, 0x92, 0xF7 }, { 0x0C, 0xE2, 0xF2 }}},
+				{{{ 0x0F, 0xDF, 0xC6 }, { 0xE0, 0x97, 0xE6 }, { 0x0F, 0xB3, 0x55 }, { 0xE0, 0x97, 0xE6 }, { 0x0F, 0x93, 0x1B }}},
+				{{{ 0x0F, 0xCE, 0x04 }, { 0xE2, 0xBB, 0x2D }, { 0x0E, 0xBA, 0x16 }, { 0xE2, 0xBB, 0x2D }, { 0x0E, 0x88, 0x1A }}},
+				{{{ 0x0F, 0x9D, 0x90 }, { 0xE0, 0xC4, 0xDF }, { 0x0F, 0x9D, 0x90 }, { 0xE0, 0xC7, 0x3C }, { 0x0F, 0x3D, 0x7E }}},
+				{{{ 0x10, 0x52, 0x4F }, { 0xE2, 0x03, 0x59 }, { 0x0D, 0xDD, 0xA6 }, { 0xE1, 0xF8, 0x58 }, { 0x0E, 0x24, 0xF4 }}},
+				{{{ 0x0F, 0xDC, 0x22 }, { 0xF9, 0xD7, 0x33 }, { 0x0E, 0x35, 0x83 }, { 0xF9, 0xD7, 0x33 }, { 0x0E, 0x11, 0xA6 }}},
+				{{{ 0x0F, 0xB6, 0xEE }, { 0xE0, 0xF2, 0xD6 }, { 0x0F, 0x6E, 0x2D }, { 0xE0, 0xF2, 0xD6 }, { 0x0F, 0x25, 0x1B }}},
+				{{{ 0x0F, 0x90, 0x6B }, { 0xEF, 0x92, 0xF7 }, { 0x0D, 0x52, 0x87 }, { 0xEF, 0x92, 0xF7 }, { 0x0C, 0xE2, 0xF2 }}},
+				{{{ 0x0F, 0xDF, 0xC6 }, { 0xE0, 0x97, 0xE6 }, { 0x0F, 0xB3, 0x55 }, { 0xE0, 0x97, 0xE6 }, { 0x0F, 0x93, 0x1B }}},
+				{{{ 0x0F, 0xCE, 0x04 }, { 0xE2, 0xBB, 0x2D }, { 0x0E, 0xBA, 0x16 }, { 0xE2, 0xBB, 0x2D }, { 0x0E, 0x88, 0x1A }}},
             }                           // end of filter set
 		}
     }
